# fsociety [![Python Version](https://img.shields.io/pypi/pyversions/fsociety?color=orange&style=flat-square)](https://www.python.org/downloads/) [![PyPi](https://img.shields.io/pypi/v/fsociety?style=flat-square)](https://pypi.org/project/fsociety/) ![GitHub repo size](https://img.shields.io/github/languages/code-size/fsociety-team/fsociety?style=flat-square) ![PyPI - Downloads](https://img.shields.io/pypi/dm/fsociety?style=flat-square) [![Docker Cloud build](https://img.shields.io/docker/cloud/build/fsocietyteam/fsociety?style=flat-square)](https://hub.docker.com/r/fsocietyteam/fsociety)

A Modular Penetration Testing Framework

[![Packages](https://img.shields.io/badge/PACKAGES.md-red?style=flat-square)](https://github.com/fsociety-team/fsociety/blob/master/PACKAGES.md) [![Changelog](https://img.shields.io/badge/CHANGELOG.md-red?style=flat-square)](https://github.com/fsociety-team/fsociety/blob/master/CHANGELOG.md)

[![fsociety](https://raw.githubusercontent.com/fsociety-team/fsociety/master/images/fsociety.png)](https://github.com/fsociety-team/fsociety)

![cli](https://raw.githubusercontent.com/fsociety-team/fsociety/master/images/cli.png)

## Install

```bash
pip install fsociety
```

## Update

```bash
pip install --upgrade fsociety
```

## Usage

```bash
usage: fsociety [-h] [-i] [-s]

A Penetration Testing Framework

optional arguments:
  -h, --help     show this help message and exit
  -i, --info     gets fsociety info
  -s, --suggest  suggest a tool
```

## Develop

```bash
git clone https://github.com/fsociety-team/fsociety.git
pip install -e ".[dev]"
```

## Docker

```bash
docker pull fsocietyteam/fsociety
docker run -it fsocietyteam/fsociety fsociety
```

## License

[![License](https://img.shields.io/pypi/l/fsociety?style=flat-square)](https://github.com/fsociety-team/fsociety/blob/master/LICENSE)

[![Twitter Follow](https://img.shields.io/badge/fuck%20it-ship%20it-blue?style=flat-square)](https://twitter.com/fsociety_team) [![Twitter Follow](https://img.shields.io/twitter/follow/fsociety_team?color=blue&style=flat-square)](https://twitter.com/fsociety_team)
